# -*- coding: utf-8 -*-
"""
Created on Jan 24 15:00:00 2019, Version 1

@author: Christian Ahlers and Marc Buckley
christian.ahlers@hotmail.de and mbuckley@udel.edu
Affiliation: Institute of Coastal Research, Helmholtz-Zentrum Geesthacht, Max-Planck-Str. 1, 21502 Geesthacht, Germany

This program allows you to sample data from a Gill Maximet Weather stationg, model GMX600 using a Raspberry Pi.
Here, the output is in default factory mode, but the program will work in any mode, just change the header accordingly.
The program generates a new text file in the same folder as this program every 30 min and writes the data.

Copyright (c) <2019> <Christian Ahlers, Marc Buckley>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

import time
from datetime import datetime
from serial import *

# set your parameters here!
ser = Serial()                                                                  
ser.port        = '/dev/ttyUSB0'                                                # choose serial port where device is plugged in
ser.baudrate    = 19200                                                         # default baud rate is 19200
ser.bytesize    = EIGHTBITS
ser.parity      = PARITY_NONE
ser.stopbits    = STOPBITS_ONE

fname = 'maximet_%y%m%d%H%M%S.dat'                                              # set filename with appendix:YYMMDDHHMMSS
fileInterval = 1800                                                             # sec, new file every 30 mins

header = 'time stamp(HHMMSS.FFF), windDir(deg), windSpeed(m/s), Cdir(deg), P(HPa), RH(perc), T(C), dewpt(C), precipT(mm), precip(mm), time stamp, voltage(V)  \n'     

# start of the code, don't change anything from here on
ser.open()                                                                      # open serial

starttime = time.time()                                                         # set start time
filename = time.strftime(fname)                                                 
fid = open(filename,'a+')                                                       # open first fid
fid.write(header)                                                               # write header into file
fid.close()

try:
    re = ' '                                                       
    while re[-1] != '\r':
        re += ser.read()
    while 1:                                                                    # eternal loop
        if time.time()- starttime > fileInterval:                               # compare current time to start time. 
            starttime = time.time()                                             # set new starttime
            fid.close()                                                         # close old file identifier
            filename = time.strftime(fname)
            fid = open(filename,'a+')                                           # create new filename and open new file identifier
            fid.write(header)
            fid.close()
            #print 'new file created'                                           # comment out if annoying
            
        re = ' '                                                       
        while re[-1] != '\r':
            re += ser.read()
            
        fid = open(filename,'a+')
        timeStamp = datetime.now().strftime('%H%M%S.%f')[:-3]
        fid.write(timeStamp+','+re[5:len(re)-10]+'\r')
        fid.close()
        print re[5:len(re)-10]

        
except KeyboardInterrupt:
    ser.close()                                                                 # close serial port
